pub enum Error<SpiError> {
Spi(SpiError),
UnexpectedStatus,
InvalidResponse,
}Expand description
The error type used by this library.
This can encapsulate an SPI or GPIO error, and adds its own protocol errors on top of that.
Variants
Spi(SpiError)
An SPI transfer failed.
UnexpectedStatus
Status register contained unexpected flags.
This can happen when the chip is faulty, incorrectly connected, or the driver wasn’t constructed or destructed properly (eg. while there is still a write in progress).
InvalidResponse
Received an invalid response from the flash memory.