pub struct Status { /* private fields */ }Expand description
Status of the flash memory.
Implementations
Sourceimpl Status
impl Status
Sourcepub fn busy(&self) -> bool
pub fn busy(&self) -> bool
Check if the flash memory is busy processing an erase or program command.
Sourcepub fn write_enable_latch(&self) -> bool
pub fn write_enable_latch(&self) -> bool
Check if the write enable latch is set.
The write enable latch must be set in order to execute an erase or program command.
Sourcepub fn protection(&self) -> u8
pub fn protection(&self) -> u8
Get the protection bits of the memory.
Each bit correponds to a region of memory that can be protected. See the datasheet of your flash memory for more details.
Sourcepub fn status_register_write_disable(&self) -> u8
pub fn status_register_write_disable(&self) -> u8
TODO: what exactly is this?